@@ -153,15 +153,16 @@ def get_kpi_df_nacional(PATH_RESULT="resultado",grupos_grados=None,lista_mr=None
     return df_resumen
 
 
-def get_test_size(X_t):
+def get_test_size(X_t=None,log=None):
     Total_X_t =  X_t.shape[0]
     Total_Test = 20000 # Cantidad minima de Test
     test_size = round(Total_Test/Total_X_t,5)
     
     min_test_size = 0.20
     if(test_size > min_test_size):
-        test_size = 0.20    
-    print("test_size : ", test_size)
+        test_size = 0.20 
+    if  log is not None and log>0 :
+        print("test_size : ", test_size)
     return test_size
 
 def export_resultado_final_nacional(alto=0.75,medio=0.5,grupos_grados=None,lista_mr=None,path="resultado",
