@@ -82,7 +82,7 @@ def print_kpis_rendimiento_modelo(y_test,y_prob_uno,dir_name,print_consola):
     
     #y_pred = np.round(y_prob_uno, 0) se estaba repitiendo
     precision, recall, f1, support = precision_recall_fscore_support(y_test, y_pred,average="binary",pos_label=1)
-    average_precision = average_precision_score(y_test, y_pred,pos_label=1)
+    average_precision = average_precision_score(y_test, y_prob_uno,pos_label=1)
     roc_auc = roc_auc_score(y_test, y_prob_uno) 
     
     if (print_consola):
