@@ -100,7 +100,7 @@ def lgb_model_skl(X_train,y_train,X_test,y_test,metric='average_precision',param
     return model
 
 
-def lgb_model_train(X_train,y_train,X_test,y_test,params=None,log=0,early_stop=400):
+def lgb_model_train(X_train,y_train,X_test,y_test,params=None,num_rounds=None,early_stop=None,log=None):
 
     d_train = lgb.Dataset(X_train, label=y_train, categorical_feature=[])
     d_valid = lgb.Dataset(X_test, label=y_test, categorical_feature=[])
@@ -110,15 +110,14 @@ def lgb_model_train(X_train,y_train,X_test,y_test,params=None,log=0,early_stop=4
     print("--------------- lgb_model_train params -------------------")
     print(params)
     print("--------------- lgb_model_train params -------------------")
-    model = lgb.train(params,                 
+    model = lgb.train(params,       
+                  num_boost_round = num_rounds,
                   train_set=d_train,
                   valid_names = ['data_valid'],
                   valid_sets=watchlist,
                   callbacks=[log_evaluation(log),early_stopping(early_stop)]
                  )
     
-    
-
     return model
 
 
