@@ -30,15 +30,16 @@ from lightgbm import early_stopping
 from lightgbm import log_evaluation
 import statistics
 
-def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,list_kpi=[],log=0):
+def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=None, list_kpi=[], n_jobs=None, metric=None, num_rounds=None,early_stop=None,log=None,random_state=42):
     folds = 5
     
-    test_size = hcm.get_test_size(X)
+    
+    test_size = hcm.get_test_size(X,log)
     if test_size == 0.20:
-        kf = StratifiedKFold(n_splits=folds, shuffle=True, random_state=1)
+        kf = StratifiedKFold(n_splits=folds, shuffle=True, random_state=random_state)
         print("StratifiedKFold")
     else:
-        kf = StratifiedShuffleSplit(n_splits=folds, test_size=test_size, random_state=1)
+        kf = StratifiedShuffleSplit(n_splits=folds, test_size=test_size, random_state=random_state)
         print("StratifiedShuffleSplit")
     
     X_train = X
@@ -66,7 +67,12 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,list_kpi=[
         train_data = X_train.iloc[train_idx,:], y_train[train_idx]
         valid_data = X_train.iloc[valid_idx,:], y_train[valid_idx]
 
-        model, kpi = fit_lgbm_with_pruning(trial, train_data, valid_data,log=log)
+        args = {
+                "trial":trial, "train":train_data, "val":valid_data, "fn_params":fn_params, "cat_features":None, 
+                "metric":metric,"n_jobs":n_jobs,"num_rounds":num_rounds,"early_stop":early_stop,"log":log,"random_state":random_state
+                }
+
+        model, kpi = fit_lgbm_with_pruning(**args)
 
         models.append(model)
         gc.collect()
@@ -170,49 +176,25 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,list_kpi=[
     list_kpi.append(result_iter)
     return mean_valid_score
 
-def fit_lgbm_with_pruning(trial, train, val, devices=(-1,),  cat_features=None, log=0):
+def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, cat_features=None,metric=None,n_jobs=1, num_rounds=None,early_stop=None,log=None,random_state=None ):
     """Train Light GBM model"""    
     X_train, y_train = train
     X_valid, y_valid = val
-
-        
-    nb_f = nbf_lgb_model.get_neg_bagging_fraction_params(y_train,{})
-
-    params = {
-
-        "seed": 1,
-        'objective': 'binary',       
-        "learning_rate": trial.suggest_loguniform("learning_rate", 1e-3, 0.01),               
-        "feature_fraction": trial.suggest_float("feature_fraction", 0.05, 0.99, step=0.05),        
-        "num_leaves": trial.suggest_int("num_leaves", 31, 2000, step=10),      
-        "bagging_fraction": trial.suggest_float("bagging_fraction", 0.05, 0.99, step=0.05),       
-        "lambda_l1": trial.suggest_loguniform('lambda_l1', 1e-8, 10.0),
-        "lambda_l2": trial.suggest_loguniform("lambda_l2", 1e-8, 10.0),
-        "min_data_in_leaf": trial.suggest_int("min_data_in_leaf", 20, 200, step=10),
-        "max_depth": trial.suggest_int("max_depth", 3, 15),
-        "min_gain_to_split": trial.suggest_float("min_gain_to_split", 0, 15), 
-        "n_estimators":10000,        
-        "metric": "average_precision",
-    }
     
-    params.update(nb_f)
+    train_params ,  dataset_params = fn_params(trial)
         
-    device = devices[0]
-    if device == -1:
-        # use cpu
-        pass
-    else:
-        # use gpu
-        print(f'using gpu device_id {device}...')
-        params.update({'device': 'gpu', 'gpu_device_id': device})
+    nb_f = nbf_lgb_model.get_neg_bagging_fraction_params(y_train,{},log)
+    
+    train_params.update(nb_f)
+    
+    params_config = {"seed": random_state, "n_jobs":n_jobs,"objective":'binary' , "metric": metric}
 
-    #params['seed'] = seed
-
-    early_stop = 400
+    train_params.update(params_config)
+    
 
 
-    d_train = lgb.Dataset(X_train, label=y_train, categorical_feature=cat_features)
-    d_valid = lgb.Dataset(X_valid, label=y_valid, categorical_feature=cat_features)
+    d_train = lgb.Dataset(X_train, label=y_train, categorical_feature=cat_features, params=dataset_params)
+    d_valid = lgb.Dataset(X_valid, label=y_valid, categorical_feature=cat_features, params=dataset_params)
 
     watchlist = [d_valid]    
 
@@ -220,7 +202,8 @@ def fit_lgbm_with_pruning(trial, train, val, devices=(-1,),  cat_features=None,
     pruning_callback_v = optuna.integration.LightGBMPruningCallback(trial, "average_precision",
                                                                   valid_name="data_valid")
     
-    model = lgb.train(params,                 
+    model = lgb.train(train_params,                 
+                      num_boost_round = num_rounds,
                       train_set=d_train,
                       valid_names = ['data_valid'],
                       valid_sets=watchlist,
@@ -257,14 +240,24 @@ def fit_lgbm_with_pruning(trial, train, val, devices=(-1,),  cat_features=None,
     return model, kpi
 
 
-def lgb_model_optuna(X_train=None, y_train=None,n_trials=2,fast_check=True,score_rs='average_precision', params=None,n_jobs = 6,log=0):
+
+  
+
+def lgb_model_optuna(X_train=None, y_train=None,n_trials=2,fast_check=True,fn_params=None, 
+                      n_jobs=None, metric=None, num_rounds=None,early_stop=None,log=None,random_state=42):
+    
+    if log == 0:
+        optuna.logging.set_verbosity(optuna.logging.ERROR)
+    
     list_kpi_ = []
-    sampler = optuna.samplers.RandomSampler(seed=10)
+    sampler = optuna.samplers.RandomSampler(seed=random_state)
     pruner=optuna.pruners.MedianPruner(n_warmup_steps=5)
     study = optuna.create_study(pruner=pruner,sampler=sampler,direction="maximize")
 
 
-    func = lambda trial: objective_with_prune(trial,fast_check=fast_check, X=X_train, y=y_train,list_kpi=list_kpi_,log=log)
+    func = lambda trial: objective_with_prune(trial,fast_check=fast_check, X=X_train, y=y_train,fn_params=fn_params, list_kpi=list_kpi_,
+                                              n_jobs=n_jobs, metric=metric, num_rounds=num_rounds,early_stop=early_stop,log=log,
+                                              random_state=random_state)
     
     study.optimize(func, n_trials=n_trials, n_jobs=n_jobs)
 
@@ -289,9 +282,9 @@ def get_best_value_nob(result_,nob_group="0.0-0.15"):
     best_value_nob = final_result['mean_valid_score'].iloc[0]
     return best_value_nob
 
-def get_params_by_value(trials_dataframe_,best_value_nob):
+def get_params_by_trial_number(trials_dataframe_,trial_number):
 
-    best_trial_nob = trials_dataframe_[trials_dataframe_.value==best_value_nob].copy()
+    best_trial_nob = trials_dataframe_[trials_dataframe_.number==trial_number].copy()
     cls_to_delete = ["number","value","datetime_start","datetime_complete","duration","state"]
     best_trial_nob.drop(columns=cls_to_delete, inplace=True)
 
